<?php

class N2GoApi
{

    public static function run()
    {
        $apikey = $_SERVER['PHP_AUTH_USER'];
        if (get_option('n2go_apikey') === $apikey) {
            $method = get_query_var('method');
            switch ($method) {
                case 'getPost':
                    $id = get_query_var('postId');
                    $result = self::getPost($id);
                    break;
                case 'test':
                    $result = array('success' => true, 'message' => 'API Connected!');
                    break;
                case 'getVersion':
                    $result = array('success' => true, 'message' => 'OK', 'version' => get_option('n2go_plugin_version'));
                    break;
                default:
                    $result = array('success' => false, 'message' => 'Invalid method call!');
                    break;
            }
        } else {
            $result = array('success' => false, 'message' => 'API Key is invalid!');
        }

        $charset = get_option('blog_charset');
        if (!headers_sent()) {
            header('HTTP/1.1 200 OK', true);
            header("Content-Type: application/json; charset=$charset", true);
        }

        echo json_encode($result);
        exit;
    }

    private static function getPost($id)
    {
        global $wpdb;
        $result = array();
        $post = $wpdb->get_row(
            $wpdb->prepare("
                SELECT 
                    p.ID as ID, 
                    p.guid as guid, 
                    p.post_content as description, 
                    p.post_title as title, 
                    p.post_date as date,
                    u.display_name as author 
                FROM $wpdb->posts p 
                    LEFT JOIN $wpdb->users u ON p.post_author = u.ID 
                WHERE p.ID = %d AND p.post_parent = 0 AND post_type = 'post'
              ", $id)
        );

        if ($post) {
            $result['post'] = array(
                'id' => $post->ID,
                'url' => esc_url(home_url('/')),
                'shortDescription' => null,
                'description' => $post->description,
                'title' => $post->title,
                'author' => $post->author,
                'date' => $post->date,
                'category' => array(),
                'tags' => array(),
                'images' => array(),
            );
            $result['post']['link'] = substr($post->guid, strlen($result['post']['url']));

            //images
            $images = $wpdb->get_results("SELECT * FROM $wpdb->posts WHERE post_mime_type LIKE 'image%' AND post_parent = $id;");
            if ($images) {
                foreach ($images as $image) {
                    $result['post']['images'][] = $image->guid;
                }
            }

            //terms
            $terms = $wpdb->get_results($wpdb->prepare("
                    SELECT ts.name as name, tx.taxonomy as type  
                    FROM $wpdb->term_relationships rs 
                        LEFT JOIN $wpdb->term_taxonomy tx ON tx.term_taxonomy_id = rs.term_taxonomy_id 
                        LEFT JOIN $wpdb->terms ts ON tx.term_id = ts.term_id 
                    WHERE rs.object_id = %d"
                    , $id));
            
            if ($terms) {
                foreach ($terms as $term) {
                    if ($term->type == 'category') {
                        $result['post']['category'][] = $term->name;
                    } else if ($term->type == 'post_tag') {
                        $result['post']['tags'][] = $term->name;
                    }
                }
            }

            $result['success'] = true;
        } else {
            $result['success'] = false;
            $result['message'] = "Post with ID = $id NOT FOUND!";
        }

        return $result;
    }
}
